@@ -81,7 +81,7 @@ def is_list_of_jsons(payload):
     except:
         return False
 
-def make_instert_string(object, table):
+def make_instert_string(object, table): ## TO BE DELETED
 
     fileds = ""
     values = ""
@@ -126,6 +126,62 @@ def make_instert_string(object, table):
 
     return insert_string
 
+def make_insert_string_v2(object, table_name, on_conflict):
+
+    fields = ""
+    values = ""
+
+    for name, value in object.items():
+
+        fields += name + ", "
+
+        if type(value) is str:
+            value = value.replace("'", "''")
+            values += "'" + value + "', "
+
+        elif type(value) is dict:
+
+            if value == {} or value == "":
+                values += "'{}', "
+
+            else:
+                string = json.dumps(value)
+                string = string.replace("'", "''")
+                value = json.loads(string)
+                values += "'" + json.dumps(value) + "', "
+
+        elif type(value) is list:
+
+            if value == [] or type(value[0]) is str:
+                value = json.dumps(value).replace('"', "'")
+                values += " ARRAY" + value + "::text[], "
+            else:
+                pass
+
+        elif type(value) is bool:
+
+            values += str(value) + ", "
+
+        elif value is None:
+
+            values += "NULL, "
+
+        else:
+            values = values + "'" + value + "', "
+
+    insert_string = "INSERT INTO " + table_name
+    insert_string += " (" + (fields[:-2]) + ")"
+    insert_string += " VALUES (" + values[:-2] + ")"
+    insert_string += " ON CONFLICT (" + on_conflict + ")"
+    insert_string += " DO NOTHING"
+
+    insert_string = insert_string.replace("'", "\'")
+
+    print("INSERT STRING: " + insert_string)
+
+    return insert_string
+
+
 
 def make_update_string(object, table, key, key_value):
 
